summaryrefslogtreecommitdiffstats
path: root/khexedit/lib
diff options
context:
space:
mode:
Diffstat (limited to 'khexedit/lib')
-rw-r--r--khexedit/lib/codecs/kbinarybytecodec.cpp4
-rw-r--r--khexedit/lib/codecs/kbytecodec.cpp4
-rw-r--r--khexedit/lib/codecs/kdecimalbytecodec.cpp12
-rw-r--r--khexedit/lib/codecs/kebcdic1047charcodec.cpp4
-rw-r--r--khexedit/lib/codecs/khexadecimalbytecodec.cpp8
-rw-r--r--khexedit/lib/codecs/koctalbytecodec.cpp12
-rw-r--r--khexedit/lib/codecs/ktextcharcodec.cpp12
-rw-r--r--khexedit/lib/codecs/ktextcharcodec.h4
-rw-r--r--khexedit/lib/kbordercolumn.cpp8
-rw-r--r--khexedit/lib/kbuffercoltextexport.cpp2
-rw-r--r--khexedit/lib/kbuffercolumn.cpp8
-rw-r--r--khexedit/lib/kbuffercolumn.h8
-rw-r--r--khexedit/lib/kbuffercursor.h8
-rw-r--r--khexedit/lib/kbufferdrag.cpp10
-rw-r--r--khexedit/lib/kbufferdrag.h2
-rw-r--r--khexedit/lib/kbufferlayout.h6
-rw-r--r--khexedit/lib/kbufferranges.h2
-rw-r--r--khexedit/lib/kbytesedit.h4
-rw-r--r--khexedit/lib/kcolumnsview.cpp4
-rw-r--r--khexedit/lib/kcursor.h2
-rw-r--r--khexedit/lib/kfixedsizebuffer.cpp6
-rw-r--r--khexedit/lib/khexedit.cpp46
-rw-r--r--khexedit/lib/khexedit.h10
-rw-r--r--khexedit/lib/koffsetcolumn.cpp4
-rw-r--r--khexedit/lib/koffsetcolumn.h2
-rw-r--r--khexedit/lib/kplainbuffer.cpp4
-rw-r--r--khexedit/lib/kvaluecolumn.cpp2
27 files changed, 99 insertions, 99 deletions
diff --git a/khexedit/lib/codecs/kbinarybytecodec.cpp b/khexedit/lib/codecs/kbinarybytecodec.cpp
index a49a460..fc9fe8d 100644
--- a/khexedit/lib/codecs/kbinarybytecodec.cpp
+++ b/khexedit/lib/codecs/kbinarybytecodec.cpp
@@ -24,7 +24,7 @@ using namespace KHE;
void KBinaryByteCodec::encode( TQString &Digits, unsigned int Pos, const unsigned char Char ) const
{
for( unsigned char M=1<<7; M>0; M>>=1 )
- Digits.at(Pos++) = (Char & M) ? '1' : '0';
+ Digits.tqat(Pos++) = (Char & M) ? '1' : '0';
}
void KBinaryByteCodec::encodeShort( TQString &Digits, unsigned int Pos, unsigned char Char ) const
@@ -36,7 +36,7 @@ void KBinaryByteCodec::encodeShort( TQString &Digits, unsigned int Pos, unsigned
break;
// now set the
for( ; M>0; M>>=1 )
- Digits.at(Pos++) = (Char & M) ? '1' : '0';
+ Digits.tqat(Pos++) = (Char & M) ? '1' : '0';
}
diff --git a/khexedit/lib/codecs/kbytecodec.cpp b/khexedit/lib/codecs/kbytecodec.cpp
index f4847ba..900055e 100644
--- a/khexedit/lib/codecs/kbytecodec.cpp
+++ b/khexedit/lib/codecs/kbytecodec.cpp
@@ -40,7 +40,7 @@ KByteCodec *KByteCodec::createCodec( KCoding C )
unsigned int KByteCodec::decode( unsigned char *Char, const TQString &Digits, uint Pos ) const
{
- //kdDebug() << TQString("KByteCodec::decode(%1,%2)").arg(Digits).arg(Pos) << endl;
+ //kdDebug() << TQString("KByteCodec::decode(%1,%2)").tqarg(Digits).tqarg(Pos) << endl;
const uint P = Pos;
// remove leading 0s
@@ -50,7 +50,7 @@ unsigned int KByteCodec::decode( unsigned char *Char, const TQString &Digits, ui
unsigned int d = encodingWidth();
do
{
- if( !appendDigit(&C,Digits.at(Pos)) )
+ if( !appendDigit(&C,Digits.tqat(Pos)) )
break;
++Pos;
diff --git a/khexedit/lib/codecs/kdecimalbytecodec.cpp b/khexedit/lib/codecs/kdecimalbytecodec.cpp
index c556875..065eb81 100644
--- a/khexedit/lib/codecs/kdecimalbytecodec.cpp
+++ b/khexedit/lib/codecs/kdecimalbytecodec.cpp
@@ -24,12 +24,12 @@ using namespace KHE;
void KDecimalByteCodec::encode( TQString &Digits, unsigned int Pos, unsigned char Char ) const
{
unsigned char C = Char / 100;
- Digits.at(Pos++) = '0'+C;
+ Digits.tqat(Pos++) = '0'+C;
Char -= C * 100;
C = Char / 10;
- Digits.at(Pos++) = '0'+C;
+ Digits.tqat(Pos++) = '0'+C;
Char -= C * 10;
- Digits.at(Pos) = '0'+Char;
+ Digits.tqat(Pos) = '0'+Char;
}
@@ -38,15 +38,15 @@ void KDecimalByteCodec::encodeShort( TQString &Digits, unsigned int Pos, unsigne
unsigned char C;
if( (C = Char / 100) )
{
- Digits.at(Pos++) = '0'+C;
+ Digits.tqat(Pos++) = '0'+C;
Char -= C * 100;
}
if( (C = Char / 10) )
{
- Digits.at(Pos++) = '0'+C;
+ Digits.tqat(Pos++) = '0'+C;
Char -= C * 10;
}
- Digits.at(Pos) = '0'+Char;
+ Digits.tqat(Pos) = '0'+Char;
}
diff --git a/khexedit/lib/codecs/kebcdic1047charcodec.cpp b/khexedit/lib/codecs/kebcdic1047charcodec.cpp
index e787715..2e91035 100644
--- a/khexedit/lib/codecs/kebcdic1047charcodec.cpp
+++ b/khexedit/lib/codecs/kebcdic1047charcodec.cpp
@@ -98,7 +98,7 @@ static const char KEBCDIC1047CharCodecName[] = "EBCDIC 1047";
bool KEBCDIC1047CharCodec::encode( char *D, const TQChar &C ) const
{
- int I = C.unicode();
+ int I = C.tqunicode();
// not in range?
if( 0x00FF < I )
return false;
@@ -119,6 +119,6 @@ const TQString& KEBCDIC1047CharCodec::name() const
const TQString& KEBCDIC1047CharCodec::codecName()
{
- static const TQString Name( TQString::fromLatin1(KEBCDIC1047CharCodecName) );
+ static const TQString Name( TQString::tqfromLatin1(KEBCDIC1047CharCodecName) );
return Name;
}
diff --git a/khexedit/lib/codecs/khexadecimalbytecodec.cpp b/khexedit/lib/codecs/khexadecimalbytecodec.cpp
index 596fd24..46abdad 100644
--- a/khexedit/lib/codecs/khexadecimalbytecodec.cpp
+++ b/khexedit/lib/codecs/khexadecimalbytecodec.cpp
@@ -41,16 +41,16 @@ bool KHexadecimalByteCodec::smallDigits() const { return Digit != BigDigit; }
void KHexadecimalByteCodec::encode( TQString &Digits, unsigned int Pos, unsigned char Char ) const
{
- Digits.at(Pos++) = Digit[Char>>4];
- Digits.at(Pos) = Digit[Char&0x0F];
+ Digits.tqat(Pos++) = Digit[Char>>4];
+ Digits.tqat(Pos) = Digit[Char&0x0F];
}
void KHexadecimalByteCodec::encodeShort( TQString &Digits, unsigned int Pos, unsigned char Char ) const
{
unsigned char C;
if( (C = (Char>>4)) )
- Digits.at(Pos++) = Digit[C];
- Digits.at(Pos) = Digit[Char&0x0F];
+ Digits.tqat(Pos++) = Digit[C];
+ Digits.tqat(Pos) = Digit[Char&0x0F];
}
diff --git a/khexedit/lib/codecs/koctalbytecodec.cpp b/khexedit/lib/codecs/koctalbytecodec.cpp
index 44c7952..7aa156d 100644
--- a/khexedit/lib/codecs/koctalbytecodec.cpp
+++ b/khexedit/lib/codecs/koctalbytecodec.cpp
@@ -23,9 +23,9 @@ using namespace KHE;
void KOctalByteCodec::encode( TQString &Digits, unsigned int Pos, unsigned char Char ) const
{
- Digits.at(Pos++) = '0'+(Char>>6);
- Digits.at(Pos++) = '0'+((Char>>3)&0x07);
- Digits.at(Pos) = '0'+((Char) &0x07);
+ Digits.tqat(Pos++) = '0'+(Char>>6);
+ Digits.tqat(Pos++) = '0'+((Char>>3)&0x07);
+ Digits.tqat(Pos) = '0'+((Char) &0x07);
}
@@ -33,10 +33,10 @@ void KOctalByteCodec::encodeShort( TQString &Digits, unsigned int Pos, unsigned
{
unsigned char C;
if( (C = (Char>>6)&0x07) )
- Digits.at(Pos++) = '0'+C;
+ Digits.tqat(Pos++) = '0'+C;
if( (C = (Char>>3)&0x07) )
- Digits.at(Pos++) = '0'+C;
- Digits.at(Pos) = '0'+((Char)&0x07);
+ Digits.tqat(Pos++) = '0'+C;
+ Digits.tqat(Pos) = '0'+((Char)&0x07);
}
diff --git a/khexedit/lib/codecs/ktextcharcodec.cpp b/khexedit/lib/codecs/ktextcharcodec.cpp
index 137c920..f5bcc65 100644
--- a/khexedit/lib/codecs/ktextcharcodec.cpp
+++ b/khexedit/lib/codecs/ktextcharcodec.cpp
@@ -16,7 +16,7 @@
// qt specific
-#include "textcodec.h"
+#include "tqtextcodec.h"
// kde specific
#include <kglobal.h>
#include <klocale.h>
@@ -127,7 +127,7 @@ const TQStringList &KTextCharCodec::codecNames()
bool Found = true;
TQTextCodec* Codec = KGlobal::charsets()->codecForName( *it, Found );
if( Found && is8Bit(Codec) )
- CodecNames.append( TQString::fromLatin1(Codec->name()) );
+ CodecNames.append( TQString::tqfromLatin1(Codec->name()) );
}
}
@@ -150,7 +150,7 @@ TQString KTextCharCodec::nameOfEncoding( KEncoding C )
if( N != 0 )
{
- TQString CodeName = TQString::fromLatin1( N );
+ TQString CodeName = TQString::tqfromLatin1( N );
}
return Codec;
}
@@ -186,10 +186,10 @@ const TQStringList &KTextCharCodec::codecNames()
for( unsigned int i=0; i<NoOfEncodings; ++i )
{
bool Found = true;
- TQString Name = TQString::fromLatin1( EncodingNames[i].Name );
+ TQString Name = TQString::tqfromLatin1( EncodingNames[i].Name );
TQTextCodec* Codec = KGlobal::charsets()->codecForName( Name, Found );
if( Found )
- CodecNames.append( TQString::fromLatin1(Codec->name()) );
+ CodecNames.append( TQString::tqfromLatin1(Codec->name()) );
}
}
@@ -231,6 +231,6 @@ KHEChar KTextCharCodec::decode( char Byte ) const
const TQString& KTextCharCodec::name() const
{
if( Name.isNull() )
- Name = TQString::fromLatin1( Codec->name() );
+ Name = TQString::tqfromLatin1( Codec->name() );
return Name;
}
diff --git a/khexedit/lib/codecs/ktextcharcodec.h b/khexedit/lib/codecs/ktextcharcodec.h
index 8d834ea..05a40ab 100644
--- a/khexedit/lib/codecs/ktextcharcodec.h
+++ b/khexedit/lib/codecs/ktextcharcodec.h
@@ -51,9 +51,9 @@ class KTextCharCodec : public KCharCodec
protected:
TQTextCodec *Codec;
- /** decodes the chars to unicode */
+ /** decodes the chars to tqunicode */
TQTextDecoder *Decoder;
- /** encodes the chars from unicode */
+ /** encodes the chars from tqunicode */
TQTextEncoder *Encoder;
/** */
mutable TQString Name;
diff --git a/khexedit/lib/kbordercolumn.cpp b/khexedit/lib/kbordercolumn.cpp
index 4a22919..170f972 100644
--- a/khexedit/lib/kbordercolumn.cpp
+++ b/khexedit/lib/kbordercolumn.cpp
@@ -49,8 +49,8 @@ void KBorderColumn::paintLine( TQPainter *P )
if( Middle )
{
- int GridColor = View->tqstyle().styleHint( TQStyle::SH_Table_GridLineColor, View );
- P->setPen( GridColor != -1 ? (TQRgb)GridColor : View->colorGroup().mid() );
+ int GridColor = View->tqstyle().tqstyleHint( TQStyle::SH_Table_GridLineColor, View );
+ P->setPen( GridColor != -1 ? (TQRgb)GridColor : View->tqcolorGroup().mid() );
P->drawLine( LineX, 0, LineX, LineHeight-1 ) ;
}
}
@@ -75,8 +75,8 @@ void KBorderColumn::paintEmptyColumn( TQPainter *P, KPixelXs Xs, KPixelYs Ys )
KPixelX LX = x() + LineX;
if( Middle && Xs.includes(LX) )
{
- int GridColor = View->tqstyle().styleHint( TQStyle::SH_Table_GridLineColor, View );
- P->setPen( GridColor != -1 ? (TQRgb)GridColor : View->colorGroup().mid() );
+ int GridColor = View->tqstyle().tqstyleHint( TQStyle::SH_Table_GridLineColor, View );
+ P->setPen( GridColor != -1 ? (TQRgb)GridColor : View->tqcolorGroup().mid() );
P->drawLine( LX, Ys.start(), LX, Ys.end() ) ;
}
}
diff --git a/khexedit/lib/kbuffercoltextexport.cpp b/khexedit/lib/kbuffercoltextexport.cpp
index 142504c..9ee6f77 100644
--- a/khexedit/lib/kbuffercoltextexport.cpp
+++ b/khexedit/lib/kbuffercoltextexport.cpp
@@ -38,7 +38,7 @@ KBufferColTextExport::KBufferColTextExport( const KBufferColumn* BufferColumn, c
: Data( D ),
CoordRange( CR )
{
- NoOfBytesPerLine = BufferColumn->layout()->noOfBytesPerLine();
+ NoOfBytesPerLine = BufferColumn->tqlayout()->noOfBytesPerLine();
Pos = new int[NoOfBytesPerLine];
// TODO: remove this hack and make it more general
diff --git a/khexedit/lib/kbuffercolumn.cpp b/khexedit/lib/kbuffercolumn.cpp
index fb2cfb9..1d26bf0 100644
--- a/khexedit/lib/kbuffercolumn.cpp
+++ b/khexedit/lib/kbuffercolumn.cpp
@@ -395,7 +395,7 @@ void KBufferColumn::paintLine( TQPainter *P, int Line ) // TODO: could be remove
void KBufferColumn::paintPositions( TQPainter *P, int Line, KSection Pos )
{
- const TQColorGroup &CG = View->colorGroup();
+ const TQColorGroup &CG = View->tqcolorGroup();
// clear background
unsigned int BlankFlag = (Pos.start()!=0?StartsBefore:0) | (Pos.end()!=LastPos?EndsLater:0);
@@ -501,7 +501,7 @@ void KBufferColumn::paintPlain( TQPainter *P, KSection Positions, int Index )
void KBufferColumn::paintSelection( TQPainter *P, KSection Positions, int Index, int Flag )
{
- const TQColorGroup &CG = View->colorGroup();
+ const TQColorGroup &CG = View->tqcolorGroup();
paintRange( P, CG.highlight(), Positions, Flag );
@@ -524,7 +524,7 @@ void KBufferColumn::paintSelection( TQPainter *P, KSection Positions, int Index,
void KBufferColumn::paintMarking( TQPainter *P, KSection Positions, int Index, int Flag )
{
- const TQColorGroup &CG = View->colorGroup();
+ const TQColorGroup &CG = View->tqcolorGroup();
paintRange( P, CG.text(), Positions, Flag );
@@ -581,7 +581,7 @@ void KBufferColumn::paintByte( TQPainter *P, int Index )
char Byte = ( Index > -1 ) ? Buffer->datum( Index ) : EmptyByte;
KHEChar B = Codec->decode( Byte );
- const TQColorGroup &CG = View->colorGroup();
+ const TQColorGroup &CG = View->tqcolorGroup();
TQColor Color = CG.text();
TQBrush Brush( CG.base(), TQt::SolidPattern );
diff --git a/khexedit/lib/kbuffercursor.h b/khexedit/lib/kbuffercursor.h
index 855b3e8..93205cc 100644
--- a/khexedit/lib/kbuffercursor.h
+++ b/khexedit/lib/kbuffercursor.h
@@ -27,10 +27,10 @@ namespace KHE
class KBufferLayout;
-/**@short navigates through the buffer in an abstract way, based on the layout
+/**@short navigates through the buffer in an abstract way, based on the tqlayout
*
* The cursor is allowed to access every coord that has content as
- * described in the layout. It holds the coord of the actual position
+ * described in the tqlayout. It holds the coord of the actual position
* and the according index in the data array.
*
* To enable the cursor to be placed behind the last position in a line
@@ -138,7 +138,7 @@ class KBufferCursor
void stepToEnd();
private:
- /** layout, tells how the column is organized */
+ /** tqlayout, tells how the column is organized */
const KBufferLayout *Layout;
/** Position in buffer */
@@ -151,7 +151,7 @@ class KBufferCursor
*/
bool Behind : 1;
- /** tells whether there could be a position behind the end of the layout */
+ /** tells whether there could be a position behind the end of the tqlayout */
bool AppendPosEnabled : 1;
};
diff --git a/khexedit/lib/kbufferdrag.cpp b/khexedit/lib/kbufferdrag.cpp
index 80b1d1c..c9cc54a 100644
--- a/khexedit/lib/kbufferdrag.cpp
+++ b/khexedit/lib/kbufferdrag.cpp
@@ -17,7 +17,7 @@
// qt specific
#include <tqcstring.h>
-#include <textcodec.h>
+#include <tqtextcodec.h>
// kde specific
#include <kglobal.h>
#include <klocale.h>
@@ -135,7 +135,7 @@ const char *KBufferDrag::format( int i ) const
}
-TQByteArray KBufferDrag::encodedData( const char *Format ) const
+TQByteArray KBufferDrag::tqencodedData( const char *Format ) const
{
if( Format != 0 )
{
@@ -166,7 +166,7 @@ TQByteArray KBufferDrag::encodedData( const char *Format ) const
{
KHEChar B = CharCodec->decode( Data[i] );
- Text.at(i) = B.isUndefined() ? KHEChar(UndefinedChar) :
+ Text.tqat(i) = B.isUndefined() ? KHEChar(UndefinedChar) :
(!B.isPrint() && B != Tab && B != Return ) ? KHEChar(SubstituteChar) : B;
}
// clean up
@@ -224,12 +224,12 @@ bool KBufferDrag::canDecode( const TQMimeSource* Source )
bool KBufferDrag::decode( const TQMimeSource* Source, TQByteArray &Dest )
{
-// Dest = Source->encodedData( MediaString );
+// Dest = Source->tqencodedData( MediaString );
// return Dest.size() != 0;
bool CanDecode = Source->provides( OctetStream );
if( CanDecode )
- Dest = Source->encodedData( OctetStream );
+ Dest = Source->tqencodedData( OctetStream );
return CanDecode;
}
diff --git a/khexedit/lib/kbufferdrag.h b/khexedit/lib/kbufferdrag.h
index 3af0ebd..effd9a2 100644
--- a/khexedit/lib/kbufferdrag.h
+++ b/khexedit/lib/kbufferdrag.h
@@ -52,7 +52,7 @@ class KBufferDrag : public TQDragObject
public: // TQDragObject API
virtual const char *format( int i ) const;
- virtual TQByteArray encodedData( const char* ) const;
+ virtual TQByteArray tqencodedData( const char* ) const;
public:
virtual void setData( const TQByteArray &);
diff --git a/khexedit/lib/kbufferlayout.h b/khexedit/lib/kbufferlayout.h
index c243225..bd92005 100644
--- a/khexedit/lib/kbufferlayout.h
+++ b/khexedit/lib/kbufferlayout.h
@@ -24,7 +24,7 @@
namespace KHE {
-/**@short the logical layout of a plain buffer view
+/**@short the logical tqlayout of a plain buffer view
*
* Given the values for
* * length of the buffer,
@@ -38,7 +38,7 @@ namespace KHE {
* * final position in this line, and
* * the total number of lines (is final line +1 or 0)
*
- * This layout sees the buffer as a continous stream of byte,
+ * This tqlayout sees the buffer as a continous stream of byte,
* thus uses each line after the start from the begin to the end.
*
* If the buffer is empty the end coord will be set one pos left to the start coord
@@ -75,7 +75,7 @@ class KBufferLayout
/** returns the coord of the end */
KBufferCoord final() const;
- /** tells how much lines this layout needs (incl. blank leading lines due to StartOffset) */
+ /** tells how much lines this tqlayout needs (incl. blank leading lines due to StartOffset) */
int noOfLines() const;
diff --git a/khexedit/lib/kbufferranges.h b/khexedit/lib/kbufferranges.h
index ed2cbce..6b293b2 100644
--- a/khexedit/lib/kbufferranges.h
+++ b/khexedit/lib/kbufferranges.h
@@ -28,7 +28,7 @@ namespace KHE
{
/** a class to control all the ranges like marking and selections
- * holds also all modified ranges and merges them so a repaint can take its info from here
+ * holds also all modified ranges and merges them so a tqrepaint can take its info from here
*
* @author Friedrich W. H. Kossebau
*/
diff --git a/khexedit/lib/kbytesedit.h b/khexedit/lib/kbytesedit.h
index eedf025..915276b 100644
--- a/khexedit/lib/kbytesedit.h
+++ b/khexedit/lib/kbytesedit.h
@@ -39,7 +39,7 @@ class KBytesEditPrivate;
* possible changes are told to the widget by repaintRange
* b) changing data ranges -> data pointer and length might change
* changes told by
- * * resetData( char *, int size, bool repaint );
+ * * resetData( char *, int size, bool tqrepaint );
* *
* 2. used as editor
* a) static data ranges
@@ -137,7 +137,7 @@ class KHEXEDIT_EXPORT KBytesEdit : public KHexEdit
*/
void setKeepsMemory( bool KM = true );
- /** repaint the indizes from i1 to i2 */
+ /** tqrepaint the indizes from i1 to i2 */
void repaintRange( int i1, int i2 );
protected:
diff --git a/khexedit/lib/kcolumnsview.cpp b/khexedit/lib/kcolumnsview.cpp
index 4bb939a..2b0b157 100644
--- a/khexedit/lib/kcolumnsview.cpp
+++ b/khexedit/lib/kcolumnsview.cpp
@@ -167,7 +167,7 @@ void KColumnsView::drawContents( TQPainter *P, int cx, int cy, int cw, int ch )
if( AffectedLines.isValid() )
{
TQPainter Paint;
- Paint.begin( const_cast<TQPixmap*>(&LineBuffer), this );
+ Paint.tqbegin( const_cast<TQPixmap*>(&LineBuffer), this );
// starting painting with the first line
KColumn *C = RedrawColumns.first();
@@ -198,7 +198,7 @@ void KColumnsView::drawContents( TQPainter *P, int cx, int cy, int cw, int ch )
break;
// to avoid flickers we first paint to the linebuffer
- Paint.begin( TQT_TQPAINTDEVICE(&LineBuffer), this );
+ Paint.tqbegin( TQT_TQPAINTDEVICE(&LineBuffer), this );
KColumn *C = RedrawColumns.first();
Paint.translate( C->x(), 0 );
diff --git a/khexedit/lib/kcursor.h b/khexedit/lib/kcursor.h
index 17b4371..bb66003 100644
--- a/khexedit/lib/kcursor.h
+++ b/khexedit/lib/kcursor.h
@@ -38,7 +38,7 @@ class KCursor
public:
/** sets size of the full cursor */
void setSize( KPixelX Width, KPixelY Height );
- /** sets the shape of the cursor to be drawn */
+ /** sets the tqshape of the cursor to be drawn */
void setShape( KPixelX X, KPixelX W );
public: // access
diff --git a/khexedit/lib/kfixedsizebuffer.cpp b/khexedit/lib/kfixedsizebuffer.cpp
index 784858c..83fd134 100644
--- a/khexedit/lib/kfixedsizebuffer.cpp
+++ b/khexedit/lib/kfixedsizebuffer.cpp
@@ -214,7 +214,7 @@ int KFixedSizeBuffer::fill( const char FChar, int FillLength, unsigned int Pos )
int KFixedSizeBuffer::compare( const KDataBuffer &Other, KSection OtherRange, unsigned int Pos )
{
- //kdDebug() << TQString("Pos: %1, OtherRange: (%3/%4)" ).arg(Pos).arg(OtherRange.start()).arg(OtherRange.end())
+ //kdDebug() << TQString("Pos: %1, OtherRange: (%3/%4)" ).tqarg(Pos).tqarg(OtherRange.start()).tqarg(OtherRange.end())
// << endl;
// test other values
if( OtherRange.startsBehind(Other.size()-1) )
@@ -245,14 +245,14 @@ int KFixedSizeBuffer::compare( const KDataBuffer &Other, KSection OtherRange, un
ValueByLength = -1;
}
//kdDebug()
- // << TQString( "Range: (%1/%2), OtherRange: (%3/%4)" ).arg(Range.start()).arg(Range.end()).arg(OtherRange.start()).arg(OtherRange.end())
+ // << TQString( "Range: (%1/%2), OtherRange: (%3/%4)" ).tqarg(Range.start()).tqarg(Range.end()).tqarg(OtherRange.start()).tqarg(OtherRange.end())
// << endl;
int oi = OtherRange.start();
for( int i=Range.start(); i<=Range.end(); ++i,++oi )
{
char OD = Other.datum(oi);
char D = Data[i];
- //kdDebug() << TQString("%1==%2").arg((int)D).arg((int)OD) << endl;
+ //kdDebug() << TQString("%1==%2").tqarg((int)D).tqarg((int)OD) << endl;
if( OD == D )
continue;
return OD < D ? 1 : -1;
diff --git a/khexedit/lib/khexedit.cpp b/khexedit/lib/khexedit.cpp
index 54726fa..01d7602 100644
--- a/khexedit/lib/khexedit.cpp
+++ b/khexedit/lib/khexedit.cpp
@@ -94,7 +94,7 @@ KHexEdit::KHexEdit( KDataBuffer *Buffer, TQWidget *Parent, const char *Name, WFl
InZooming( false ),
d( 0 )
{
- // initalize layout
+ // initalize tqlayout
if( DataBuffer )
BufferLayout->setLength( DataBuffer->size() );
BufferLayout->setNoOfLinesPerPage( noOfLinesPerPage() );
@@ -199,7 +199,7 @@ void KHexEdit::setOverwriteMode( bool OM )
OverWrite = OM;
// affected:
- // cursor shape
+ // cursor tqshape
bool ChangeCursor = !( CursorPaused || ValueEditor->isInEditMode() );
if( ChangeCursor )
pauseCursor();
@@ -548,17 +548,17 @@ void KHexEdit::toggleOffsetColumn( bool Visible )
}
-TQSize KHexEdit::sizeHint() const
+TQSize KHexEdit::tqsizeHint() const
{
return TQSize( totalWidth(), totalHeight() );
}
-TQSize KHexEdit::minimumSizeHint() const
+TQSize KHexEdit::tqminimumSizeHint() const
{
// TODO: better minimal width (visibility!)
return TQSize( OffsetColumn->visibleWidth()+FirstBorderColumn->visibleWidth()+SecondBorderColumn->visibleWidth()+valueColumn().byteWidth()+charColumn().byteWidth(),
- lineHeight() + noOfLines()>1? tqstyle().pixelMetric(TQStyle::PM_ScrollBarExtent):0 );
+ lineHeight() + noOfLines()>1? tqstyle().tqpixelMetric(TQStyle::PM_ScrollBarExtent):0 );
}
@@ -598,7 +598,7 @@ int KHexEdit::fittingBytesPerLine( const TQSize &NewSize ) const
// check influence of dis-/appearing of the vertical scrollbar
bool VerticalScrollbarIsVisible = verticalScrollBar()->isVisible();
- KPixelX ScrollbarExtent = tqstyle().pixelMetric( TQStyle::PM_ScrollBarExtent );//verticalScrollBar()->width();
+ KPixelX ScrollbarExtent = tqstyle().tqpixelMetric( TQStyle::PM_ScrollBarExtent );//verticalScrollBar()->width();
KPixelX AvailableWidth = FullWidth;
if( VerticalScrollbarIsVisible )
@@ -850,7 +850,7 @@ void KHexEdit::cut()
if( !Drag )
return;
- TQApplication::clipboard()->setData( Drag, ClipboardMode );
+ TQApplication::tqclipboard()->setData( Drag, ClipboardMode );
removeSelectedData();
}
@@ -862,7 +862,7 @@ void KHexEdit::copy()
if( !Drag )
return;
- TQApplication::clipboard()->setData( Drag, ClipboardMode );
+ TQApplication::tqclipboard()->setData( Drag, ClipboardMode );
}
@@ -871,7 +871,7 @@ void KHexEdit::paste()
if( isReadOnly() )
return;
- TQMimeSource *Source = TQApplication::clipboard()->data( ClipboardMode );
+ TQMimeSource *Source = TQApplication::tqclipboard()->data( ClipboardMode );
pasteFromSource( Source );
}
@@ -1042,7 +1042,7 @@ void KHexEdit::updateLength()
void KHexEdit::clipboardChanged()
{
// don't listen to selection changes
- disconnect( TQApplication::clipboard(), TQT_SIGNAL(selectionChanged()), this, 0 );
+ disconnect( TQApplication::tqclipboard(), TQT_SIGNAL(selectionChanged()), this, 0 );
selectAll( false );
}
@@ -1192,11 +1192,11 @@ bool KHexEdit::eventFilter( TQObject *O, TQEvent *E )
// if( O == this && E->type() == TQEvent::PaletteChange )
// {
-// TQColor old( viewport()->colorGroup().color(TQColorGroup::Text) );
+// TQColor old( viewport()->tqcolorGroup().color(TQColorGroup::Text) );
//
-// if( old != colorGroup().color(TQColorGroup::Text) )
+// if( old != tqcolorGroup().color(TQColorGroup::Text) )
// {
-// TQColor c( colorGroup().color(TQColorGroup::Text) );
+// TQColor c( tqcolorGroup().color(TQColorGroup::Text) );
// doc->setMinimumWidth( -1 );
// doc->setDefaultFormat( doc->formatCollection()->defaultFormat()->font(), c );
// lastFormatted = doc->firstParagraph();
@@ -1275,15 +1275,15 @@ void KHexEdit::createCursorPixmaps()
int Index = BufferCursor->validIndex();
TQPainter Paint;
- Paint.begin( const_cast<TQPixmap*>(&CursorPixmaps->offPixmap()), this );
+ Paint.tqbegin( const_cast<TQPixmap*>(&CursorPixmaps->offPixmap()), this );
activeColumn().paintByte( &Paint, Index );
Paint.end();
- Paint.begin( const_cast<TQPixmap*>(&CursorPixmaps->onPixmap()), this );
+ Paint.tqbegin( const_cast<TQPixmap*>(&CursorPixmaps->onPixmap()), this );
activeColumn().paintCursor( &Paint, Index );
Paint.end();
- // calculat the shape
+ // calculat the tqshape
KPixelX CursorX;
KPixelX CursorW;
if( BufferCursor->isBehind() )
@@ -1498,7 +1498,7 @@ void KHexEdit::paintLine( KBufferColumn *C, int Line, KSection Positions )
// to avoid flickers we first paint to the linebuffer
TQPainter Paint;
- Paint.begin( &LineBuffer, this );
+ Paint.tqbegin( &LineBuffer, this );
Paint.translate( C->x(), 0 );
C->paintPositions( &Paint, Line, Positions );
@@ -1671,14 +1671,14 @@ void KHexEdit::contentsMouseReleaseEvent( TQMouseEvent *e )
// was end of selection operation?
else if( BufferRanges->hasSelection() )
{
- if( TQApplication::clipboard()->supportsSelection() )
+ if( TQApplication::tqclipboard()->supportsSelection() )
{
ClipboardMode = TQClipboard::Selection;
- disconnect( TQApplication::clipboard(), TQT_SIGNAL(selectionChanged()), this, 0);
+ disconnect( TQApplication::tqclipboard(), TQT_SIGNAL(selectionChanged()), this, 0);
copy();
- connect( TQApplication::clipboard(), TQT_SIGNAL(selectionChanged()), this, TQT_SLOT(clipboardChanged()) );
+ connect( TQApplication::tqclipboard(), TQT_SIGNAL(selectionChanged()), this, TQT_SLOT(clipboardChanged()) );
ClipboardMode = TQClipboard::Clipboard;
}
}
@@ -2005,14 +2005,14 @@ void KHexEdit::contentsContextMenuEvent( TQContextMenuEvent *e )
{
selectAll();
// if the clipboard support selections, put the newly selected text into the clipboard
- if( TQApplication::clipboard()->supportsSelection() )
+ if( TQApplication::tqclipboard()->supportsSelection() )
{
ClipboardMode = TQClipboard::Selection;
- disconnect( TQApplication::clipboard(), TQT_SIGNAL(selectionChanged()), this, 0);
+ disconnect( TQApplication::tqclipboard(), TQT_SIGNAL(selectionChanged()), this, 0);
copy();
- connect( TQApplication::clipboard(), TQT_SIGNAL(selectionChanged()), this, TQT_SLOT(clipboardChanged()) );
+ connect( TQApplication::tqclipboard(), TQT_SIGNAL(selectionChanged()), this, TQT_SLOT(clipboardChanged()) );
ClipboardMode = TQClipboard::Clipboard;
}
}
diff --git a/khexedit/lib/khexedit.h b/khexedit/lib/khexedit.h
index 84193dd..00a25d6 100644
--- a/khexedit/lib/khexedit.h
+++ b/khexedit/lib/khexedit.h
@@ -19,7 +19,7 @@
#define KHE_KHEXEDIT_H
// qt specific
-#include <clipboard.h>
+#include <tqclipboard.h>
// lib specific
// #include "khe.h"
#include "khexedit_export.h"
@@ -130,8 +130,8 @@ class KHEXEDIT_EXPORT KHexEdit : public KColumnsView
// void focusOutEvent( TQFocusEvent *FocusEvent );
virtual bool eventFilter( TQObject *O, TQEvent *E );
- virtual TQSize sizeHint() const;
- virtual TQSize minimumSizeHint() const;
+ virtual TQSize tqsizeHint() const;
+ virtual TQSize tqminimumSizeHint() const;
public: // value access
@@ -425,7 +425,7 @@ class KHEXEDIT_EXPORT KHexEdit : public KColumnsView
protected:
/** recalcs all dependant values with the actual NoOfBytesPerLine */
void adjustToLayoutNoOfBytesPerLine();
- /** recalcs a layout due to the resize style that fits into the view size
+ /** recalcs a tqlayout due to the resize style that fits into the view size
* and updates the dependant values
*/
void adjustLayoutToSize();
@@ -452,7 +452,7 @@ class KHEXEDIT_EXPORT KHexEdit : public KColumnsView
/** Buffer with the data */
KDataBuffer *DataBuffer;
- /** holds the logical layout */
+ /** holds the logical tqlayout */
KBufferLayout *BufferLayout;
/** */
KBufferCursor *BufferCursor;
diff --git a/khexedit/lib/koffsetcolumn.cpp b/khexedit/lib/koffsetcolumn.cpp
index 43897b1..c2be15a 100644
--- a/khexedit/lib/koffsetcolumn.cpp
+++ b/khexedit/lib/koffsetcolumn.cpp
@@ -42,7 +42,7 @@ KOffsetColumn::~KOffsetColumn()
void KOffsetColumn::paintLine( TQPainter *P, int Line )
{
- const TQColor &ButtonColor = View->colorGroup().button();
+ const TQColor &ButtonColor = View->tqcolorGroup().button();
P->fillRect( 0,0,width(),LineHeight, TQBrush(ButtonColor,TQt::SolidPattern) );
printFunction()( CodedOffset,FirstLineOffset+Delta*Line );
@@ -68,7 +68,7 @@ void KOffsetColumn::paintEmptyColumn( TQPainter *P, KPixelXs Xs, KPixelYs Ys )
{
Xs.restrictTo( XSpan );
- const TQColor &ButtonColor = View->colorGroup().button();
+ const TQColor &ButtonColor = View->tqcolorGroup().button();
P->fillRect( Xs.start(), Ys.start(), Xs.width(), Ys.width(), TQBrush(ButtonColor,TQt::SolidPattern) );
}
diff --git a/khexedit/lib/koffsetcolumn.h b/khexedit/lib/koffsetcolumn.h
index 497d7ef..56b48f1 100644
--- a/khexedit/lib/koffsetcolumn.h
+++ b/khexedit/lib/koffsetcolumn.h
@@ -81,7 +81,7 @@ class KOffsetColumn : public KColumn
/** */
KPixelY DigitBaseLine;
- protected: // general layout
+ protected: // general tqlayout
KOffsetFormat::KFormat Format;
int CodingWidth;
diff --git a/khexedit/lib/kplainbuffer.cpp b/khexedit/lib/kplainbuffer.cpp
index 02b9d70..08874ba 100644
--- a/khexedit/lib/kplainbuffer.cpp
+++ b/khexedit/lib/kplainbuffer.cpp
@@ -72,7 +72,7 @@ int KPlainBuffer::insert( int Pos, const char* D, int Length )
// check all parameters
if( Length == 0 )
return 0;
- //kdDebug() << TQString("before: Size: %1, RawSize: %2").arg(Size).arg(RawSize) << endl;
+ //kdDebug() << TQString("before: Size: %1, RawSize: %2").tqarg(Size).tqarg(RawSize) << endl;
// correct for appending
if( Pos > (int)Size )
Pos = Size;
@@ -82,7 +82,7 @@ int KPlainBuffer::insert( int Pos, const char* D, int Length )
// copy new data to its place
memcpy( &Data[Pos], D, Length );
- //kdDebug() << TQString("after: Size: %1, RawSize: %2").arg(Size).arg(RawSize) << endl;
+ //kdDebug() << TQString("after: Size: %1, RawSize: %2").tqarg(Size).tqarg(RawSize) << endl;
Modified = true;
return Length;
diff --git a/khexedit/lib/kvaluecolumn.cpp b/khexedit/lib/kvaluecolumn.cpp
index 645dc89..beb706a 100644
--- a/khexedit/lib/kvaluecolumn.cpp
+++ b/khexedit/lib/kvaluecolumn.cpp
@@ -105,7 +105,7 @@ void KValueColumn::paintEditedByte( TQPainter *P, char Byte, const TQString &Edi
{
KHEChar B = Codec->decode( Byte );
- const TQColorGroup &CG = View->colorGroup();
+ const TQColorGroup &CG = View->tqcolorGroup();
P->fillRect( 0,0,ByteWidth,LineHeight, TQBrush(colorForChar(B),TQt::SolidPattern) );
diff --git a/khexedit/lib/kbuffercolumn.h b/khexedit/lib/kbuffercolumn.h
index 10e930d..47f21d1 100644
--- a/khexedit/lib/kbuffercolumn.h
+++ b/khexedit/lib/kbuffercolumn.h
@@ -39,7 +39,7 @@ class KCharCodec;
const int NoByteFound = -1;
/** base class of all buffer column displayers
* holds all information about the vertical layout of a buffer column
* knows how to paint the data and the editing things (focus, cursor, selection)
* but does not offer
*
@@ -154,7 +154,7 @@ class KBufferColumn : public KColumn
int firstPos() const;
int lastPos() const;
KSection visiblePositions() const;
- const KBufferLayout *layout() const;
+ const KBufferLayout *tqlayout() const;
KCharCodec* codec() const;
protected:
@@ -184,7 +184,7 @@ class KBufferColumn : public KColumn
protected:
/** pointer to the buffer */
KDataBuffer *Buffer;
/** pointer to the layout */
const KBufferLayout *Layout;
/** pointer to the ranges */
KBufferRanges *Ranges;
@@ -242,7 +242,7 @@ inline int KBufferColumn::firstPos() const { return PaintPositions.start(); }
inline int KBufferColumn::lastPos() const { return PaintPositions.end(); }
inline KSection KBufferColumn::visiblePositions() const { return PaintPositions; }
-inline const KBufferLayout *KBufferColumn::layout() const { return Layout; }
+inline const KBufferLayout *KBufferColumn::tqlayout() const { return Layout; }
inline void KBufferColumn::setCodec( KCharCodec *C ) { Codec = C; }
@@ -39,7 +39,7 @@ class KCharCodec;
const int NoByteFound = -1;
/** base class of all buffer column displayers
- * holds all information about the vertical layout of a buffer column
+ * holds all information about the vertical tqlayout of a buffer column
* knows how to paint the data and the editing things (focus, cursor, selection)
* but does not offer
@@ -184,7 +184,7 @@ class KBufferColumn : public KColumn
/** pointer to the buffer */
KDataBuffer *Buffer;
- /** pointer to the layout */
+ /** pointer to the tqlayout */
const KBufferLayout *Layout;
/** pointer to the ranges */